.. :changelog:

History
-------

0.1.3 (2018-02-12)
++++++++++++++++++

* Add commands to Makefile to simplify the package build and release process

0.1.2 (2018-02-12)
++++++++++++++++++

* Modify setup.py to enable the usage of bumpversion.

0.1.1 (2018-02-12)
++++++++++++++++++

* Allow the Redis connection details to be customizable.

0.1.0 (2018-01-19)
++++++++++++++++++

* First release on PyPI.
